package ch.ethz.inf.dbproject.model.test;

import static org.junit.Assert.assertEquals;

import java.io.StringReader;

import org.junit.Test;

import ch.ethz.inf.dbproject.model.simpleDatabase.operators.Operator;
import ch.ethz.inf.dbproject.model.simpleDatabase.operators.Project;
import ch.ethz.inf.dbproject.model.simpleDatabase.operators.Scan;
import ch.ethz.inf.dbproject.model.simpleDatabase.operators.Select;

/**
 * Unit tests for Part 2.
 * @author Martin Hentschel
 */
public class Part2Test {

	private String[] schema = new String[] { "id", "name", "age" };
	private String relation = "1,Max,20\n2,Moritz,22\n3,Theo,34";

	@Test
	public void testScan() {
		Operator op = new Scan(new StringReader(relation), schema);
		String expected = "1,Max,20 2,Moritz,22 3,Theo,34";
		String actual = concatTuples(op);
		assertEquals(expected, actual);
	}

	@Test
	public void testSelect() {
		Operator op = new Select<String>(new Scan(new StringReader(relation), schema), "age", "22");
		String expected = "2,Moritz,22";
		String actual = concatTuples(op);
		assertEquals(expected, actual);
	}

	@Test
	public void testProject() {
		Operator op = new Project(new Scan(new StringReader(relation), schema), "name");
		String expected = "Max Moritz Theo";
		String actual = concatTuples(op);
		assertEquals(expected, actual);
	}

	@Test
	public void testProject2() {
		String[] columns = new String[] { "age", "id" };
		Operator op = new Project(new Scan(new StringReader(relation), schema), columns);
		String expected = "20,1 22,2 34,3";
		String actual = concatTuples(op);
		assertEquals(expected, actual);
	}

	@Test
	public void testSelectProject() {
		Operator op = new Project(new Select<String>(new Scan(new StringReader(relation), schema), "age", "22"), "name");
		String expected = "Moritz";
		String actual = concatTuples(op);
		assertEquals(expected, actual);
	}

	/**
	 * Concatenates all tuples returned by the operator. The tuples are separated
	 * by a simple space.
	 * @param op operator to read from
	 * @return concatenated tuples
	 */
	private String concatTuples(Operator op) {
		StringBuilder buf = new StringBuilder();
		while (op.moveNext()) {
			buf.append(op.current().toString());
			buf.append(" ");
		}
		// delete last space
		//buf.deleteCharAt(buf.length() - 1);
		return buf.toString();
	}
}
